==> free-sa-1.6.2.tar.gz: free-sa-1.6.2/src/reports/r_topsites.c <==
#include "global.h"


FILE *tTS1;


void ReportTopSites(void) {
    FILE *TSR, *tTS2;
    char turl[URLSIZE], oturl[URLSIZE], tname[USERNAMESIZE], tfname[FILENAMESIZE];
    char *iname;
    double tBytes, urlBytes = 0;
    int tCount, urlNumber = 0;
    short int tIndic, urlIndic = 0;
    int i;

    SAfclose(tTS1, icfg.TSRname);

    /* sort by URL and internal name, i don't know why it's faster than sorting by url only */
    SAsnprintf(turl, sizeof(turl), "%s/%s.uns", cfg.TmpDir, icfg.TSRname);
    SAsnprintf(tfname, sizeof(tfname), "%s/%s", cfg.TmpDir, icfg.TSRname);
    SAsystem(CMDSORT, CMDSORT, "-k", "1,2", "-o", tfname, turl, NULL);
    SAunlink(turl);

    oturl[0] = '\0';
    iname = (char *)SAmalloc((size_t)(icfg.ueCount * USERDESCSIZE));
	
    tTS1 = SAfopenI("r", tfname);
    tTS2 = SAfopenI("w", turl);

    while (fscanf(tTS1, "%s %s %d %lf %hd\n", turl, tname, &tCount, &tBytes, &tIndic) == 5) {
        if (strcmp(oturl, turl)) {
    	    if (oturl[0] != '\0') SAfprintf(tTS2, "%s %d %.0f %hd %s\n", oturl, urlNumber, urlBytes, urlIndic, iname);
		    
	    strcpy(oturl, turl);
	    strcpy(iname, tname);
	    urlNumber = tCount;
	    urlIndic = tIndic;
	    urlBytes = tBytes;
	} else {
	    /* fix for incorrect for us sorting, ex: http://m.ru & http://www.m.ru.net */
	    if (strcmp(iname, tname)) SAsnprintf(&iname[strlen(iname)], USERDESCSIZE + 2L, ", %s", tname);
	    urlNumber += tCount;
	    urlIndic |= tIndic;
	    urlBytes += tBytes;
	}
    }
    
    /* write last data (because we use postwriting, not prewriting) */
    SAfprintf(tTS2, "%s %d %.0f %hd %s\n", oturl, urlNumber, urlBytes, urlIndic, iname);

    SAfcloseU(tTS1, tfname);
    SAfclose(tTS2, icfg.TSRname);

    /* sort by bytes (or required field) */
    SAsnprintf(turl, sizeof(turl), "%s/%s.uns", cfg.TmpDir, icfg.TSRname);
    SAsnprintf(tfname, sizeof(tfname), "%s/%s", cfg.TmpDir, icfg.TSRname);
    SAsystem(CMDSORT, CMDSORT, "-k", "3,3nr", "-o", tfname, turl, NULL);
    SAunlink(turl);

    i = 1;
    tTS1 = SAfopenI("r", tfname);
    SAsnprintf(turl, sizeof(turl), "%s (%s)", loc->Bytes, loc->Desc);
    TSR = SAfopenH("../", 'r', loc->TopSites, turl, 1, "w", "%s/%s.html", icfg.ReportDir, icfg.TSRname);
    SAfprintf(TSR, "<tr><th>%s<th>%s<th>%s<th>%s<th>%s\n", 
	    loc->No, loc->URL, loc->Connections, loc->Bytes, loc->Users);
    while(fscanf(tTS1, "%s %d %lf %hd %[^\n]", turl, &tCount, &tBytes, &tIndic, iname) == 5) {
	SAfprintf(TSR, "<tr><td>%d<td class=lt><a href=\"%s\">%s</a><td>%"SATSEP"d<td>%s<td class=lt>%s", 
		i++, turl, turl, tCount, icfg.SAB(tBytes), iname);
	Indics(TSR, tIndic);
	
	if (cfg.TSLimit) if (i > cfg.TSLimit) break;
    }
    SAfcloseH(TSR, icfg.TSRname);
    SAfcloseU(tTS1, tfname);
}

==> free-sa-2.0.0b2.tar.gz: free-sa-2.0.0b2/src/reports/r_topsites.c <==
#include "global.h"


FILE *tTS1;


void ReportTopSites(void) {
    FILE *TSR, *tTS2;
    char turl[URLSIZE], oturl[URLSIZE], tname[USERNAMESIZE], tfname[FILENAMESIZE];
    char *iname;
    double tBytes, urlBytes = 0;
    int tCount, urlNumber = 0;
    short int tIndic, urlIndic = 0;
    int i;


    SAfclose(tTS1);

    /* sort by URL and internal name, i don't know why it's faster than sorting by url only */
    SAsnprintf(turl, sizeof(turl), "%s/%s.uns", cfg.cache_directory, icfg.TSRname);
    SAsnprintf(tfname, sizeof(tfname), "%s/%s", cfg.cache_directory, icfg.TSRname);
    SAsystem(CMDSORT, CMDSORT, "-k", "1,2", "-o", tfname, turl, NULL);
    SAunlink(turl);

    oturl[0] = '\0';
    iname = (char *)SAmalloc((size_t)(icfg.ueCount * USERDESCSIZE));
	
    tTS1 = SAfopenI("r", tfname);
    tTS2 = SAfopenI("w", turl);

    while (fscanf(tTS1, "%s %s %d %lf %hd\n", turl, tname, &tCount, &tBytes, &tIndic) == 5) {
        if (strcmp(oturl, turl)) {
    	    if (oturl[0] != '\0') SAfprintf(tTS2, "%s %d %.0f %hd %s\n", oturl, urlNumber, urlBytes, urlIndic, iname);
		    
	    strcpy(oturl, turl);
	    strcpy(iname, tname);
	    urlNumber = tCount;
	    urlIndic = tIndic;
	    urlBytes = tBytes;
	} else {
	    /* fix for incorrect for us sorting, ex: http://m.ru & http://www.m.ru.net */
	    if (strcmp(iname, tname)) SAsnprintf(&iname[strlen(iname)], USERDESCSIZE + 2L, ", %s", tname);
	    urlNumber += tCount;
	    urlIndic |= tIndic;
	    urlBytes += tBytes;
	}
    }
    
    /* write last data (because we use postwriting, not prewriting) */
    SAfprintf(tTS2, "%s %d %.0f %hd %s\n", oturl, urlNumber, urlBytes, urlIndic, iname);

    SAfcloseU(tTS1, tfname);
    SAfclose(tTS2);

    /* sort by bytes (or required field) */
    SAsnprintf(turl, sizeof(turl), "%s/%s.uns", cfg.cache_directory, icfg.TSRname);
    SAsnprintf(tfname, sizeof(tfname), "%s/%s", cfg.cache_directory, icfg.TSRname);
    SAsystem(CMDSORT, CMDSORT, "-k", "3,3nr", "-o", tfname, turl, NULL);
    SAunlink(turl);

    i = 1;
    tTS1 = SAfopenI("r", tfname);
    SAsnprintf(turl, sizeof(turl), "%s (%s)", loc->Bytes, loc->Desc);
    TSR = SAfopenH("../", 'r', loc->TopSites, turl, 1, "%s/%s.html", icfg.ReportDir, icfg.TSRname);
    SAfprintf(TSR, "<tr><th>%s<th>%s<th>%s<th>%s<th>%s\n", 
	    loc->No, loc->URL, loc->Connections, loc->Bytes, loc->Users);
    while(fscanf(tTS1, "%s %d %lf %hd %[^\n]", turl, &tCount, &tBytes, &tIndic, iname) == 5) {
	SAfprintf(TSR, "<tr><td>%d<td class=lt><a href=\"%s\">%s</a><td>%"SATSEP"d<td>%s<td class=lt>%s", 
		i++, turl, turl, tCount, icfg.SAB(tBytes), iname);
	Indics(TSR, tIndic);
	
	if (cfg.top_sites_limit) if (i > cfg.top_sites_limit) break;
    }
    SAfcloseH(TSR);
    SAfcloseU(tTS1, tfname);
}
